###############################################################################
# OpenVAS Vulnerability Test
# $Id$
#
# FormMail Detection
#
# Authors:
# Michael Meyer
#
# Copyright:
# Copyright (c) 2009 Michael Meyer
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# (or any later version), as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
###############################################################################

# need desc here to modify it later in script.
desc["english"] = "

 Overview:
  The FormMail Script was found at this port. FormMail is a generic
  HTML form to e-mail gateway that parses the results of any form and
  sends them to the specified users. 

 See also:
  http://www.scriptarchive.com/formmail.html

 Risk factor : None";

if (description)
{
 script_id(100201);
 script_version ("1.0");

 script_name(english:"FormMail Detection");  

 script_description(english:desc["english"]);
 script_summary(english:"Checks for the presence of FormMail");
 script_category(ACT_GATHER_INFO);
 script_family(english:"Service detection");
 script_copyright(english:"This script is Copyright (C) 2009 Michael Meyer");
 script_dependencie("find_service.nes", "http_version.nasl");
 script_require_ports("Services/www", 80);
 script_exclude_keys("Settings/disable_cgi_scanning");
 exit(0);
}

include("http_func.inc");
include("http_keepalive.inc");
include("global_settings.inc");

port = get_http_port(default:80);

if(!get_port_state(port))exit(0);

dirs = make_list("/formmail", cgi_dirs());
files = make_list("formmail.pl","FormMail.pl");

foreach dir (dirs) {
 foreach file (files) {

   url = string(dir, "/", file); 
   req = http_get(item:url, port:port);
   buf = http_send_recv(port:port, data:req, bodyonly:FALSE);  

   if( buf == NULL )continue;

   if( egrep(pattern: 'FormMail', string: buf, icase: TRUE) &&
      (egrep(pattern: 'A Free Product of', string: buf, icase: TRUE) ||
       egrep(pattern: 'Bad Referrer', string: buf, icase: TRUE) ) )
   { 
   
     if(strlen(dir)>0) {
        install=dir;
     } else {
        install=string("/");
     }

      vers = string("unknown");

      ### try to get version.
      version = eregmatch(string: buf, pattern: 'FormMail.*v([0-9.]+)',icase:TRUE);
    
      if ( !isnull(version[1]) ) {
         vers=version[1];
      } 

      set_kb_item(name: string("www/", port, "/FormMail"), value: string(vers, " under ", install));	
      set_kb_item(name: string("www/", port, "/FormMail/file"), value: file);

      info = string("None\n\nFormMail Version '");
      info += string(vers);
      info += string("' was detected on the remote host\n");

      desc = ereg_replace(
          string:desc["english"],
          pattern:"None$",
          replace:info
      );    
       
         if(report_verbosity > 0) {
           security_note(port:port,data:string(desc));
           exit(0);
         }	 
   }
 }  
}

exit(0);
