###############################################################################
# OpenVAS Vulnerability Test
# $Id$
#
# e107 Detection
#
# Authors:
# Michael Meyer
#
# Copyright:
# Copyright (c) 2009 Michael Meyer
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# (or any later version), as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
###############################################################################

# need desc here to modify it later in script.
desc["english"] = "

 Overview:
  This host is running e107, a content management system written in
  PHP and using the popular open source MySQL database system for
  content storage.  

 See also:
  http://e107.org/

 Risk factor : None";

if (description)
{
 script_id(100133);
 script_version ("1.0");

 script_name(english:"e107 Detection");  

 script_description(english:desc["english"]);
 script_summary(english:"Checks for the presence of e107");
 script_category(ACT_GATHER_INFO);
 script_family(english:"General");
 script_copyright(english:"This script is Copyright (C) 2009 Michael Meyer");
 script_dependencie("find_service.nes", "http_version.nasl");
 script_require_ports("Services/www", 80);
 script_exclude_keys("Settings/disable_cgi_scanning");
 exit(0);
}

include("http_func.inc");
include("http_keepalive.inc");
include("global_settings.inc");

port = get_http_port(default:80);

if(!get_port_state(port))exit(0);
if(!can_host_php(port:port))exit(0);

dirs = make_list("/e107","/cms",cgi_dirs());
foreach dir (dirs) {

 url = string(dir, "/e107_admin/admin.php"); 
 req = http_get(item:url, port:port);
 buf = http_keepalive_send_recv(port:port, data:req, bodyonly:FALSE);  
 if( buf == NULL )continue;
 if(egrep(pattern: 'This site is powered by <a.*e107.org.*[^>]+>e107</a>', string: buf, icase: TRUE))
 { 
     if(strlen(dir)>0) {
        install=dir;
     } else {
        install=string("/");
     }  
    
    vers = string("unknown");

    ### try to get version. Not possible...
    #version = eregmatch(string: buf, pattern: "",icase:TRUE, multiline: TRUE);
    
    #if ( !isnull(version[1]) ) {
    #   vers=chomp(version[1]);
    #} 
    
    set_kb_item(name: string("www/", port, "/e107"), value: string(vers," under ",install));

    info = string("None\n\ne107 Version '");
    info += string(vers);
    info += string("' was detected on the remote host in the following directory(s):\n\n");
    info += string(install, "\n"); 

    desc = ereg_replace(
        string:desc["english"],
        pattern:"None$",
        replace:info
    );    
       
       if(report_verbosity > 0) {
         security_note(port:port,data:desc);
       }
       exit(0);
  
 }
}
exit(0);
