###############################################################################
# OpenVAS Vulnerability Test
#
# RedHat Update for samba RHSA-2008:0290-01
#
# Authors:
# System Generated Check
#
# Copyright:
# Copyright (c) 2009 Intevation GmbH, http://www.intevation.net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# (or any later version), as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
###############################################################################

if(description)
{
  script_id(870003);
  script_version("$Revision: 1.0 $");
  script_xref(name: "RHSA", value: "2008:0290-01");
  script_cve_id("CVE-2008-1105");
  script_name(english: "RedHat Update for samba RHSA-2008:0290-01");
  desc["english"] = "

  Vulnerability Insight:
  Samba is a suite of programs used by machines to share files, printers, and
  other information.
  
  A heap-based buffer overflow flaw was found in the way Samba clients handle
  over-sized packets. If a client connected to a malicious Samba server, it
  was possible to execute arbitrary code as the Samba client user. It was
  also possible for a remote user to send a specially crafted print request
  to a Samba server that could result in the server executing the vulnerable
  client code, resulting in arbitrary code execution with the permissions of
  the Samba server. (CVE-2008-1105)
  
  Red Hat would like to thank Alin Rad Pop of Secunia Research for
  responsibly disclosing this issue.
  
  This update also addresses two issues which prevented Samba from joining
  certain Windows domains with tightened security policies, and prevented
  certain signed SMB content from working as expected:
  
  * when some Windows® 2000-based domain controllers were set to use
  mandatory signing, Samba clients would drop the connection because of an
  error when generating signatures. This presented as a &quot;Server packet had
  invalid SMB signature&quot; error to the Samba client. This update corrects the
  signature generation error.
  
  * Samba servers using the &quot;net ads join&quot; command to connect to a Windows
  Server® 2003-based domain would fail with &quot;failed to get schannel session
  key from server&quot; and &quot;NT_STATUS_ACCESS_DENIED&quot; errors. This update
  correctly binds to the NETLOGON share, allowing Samba servers to connect to
  the domain properly.
  
  Users of Samba are advised to upgrade to these updated packages, which
  contain a backported patch to resolve these issues.


  Affected Software/OS:
  samba on Red Hat Enterprise Linux (v. 5 server)

  Fix: Please Install the Updated Packages.

  References:
  https://www.redhat.com/archives/rhsa-announce/2008-May/msg00026.html

  Risk factor: High";

  script_description(english:desc["english"]);
  script_summary(english:"Check for the Version of samba");
  script_category(ACT_GATHER_INFO);
  script_copyright(english:"Copyright (C) 2009 Intevation GmbH");
  script_family(english:"Red Hat Local Security Checks");
  script_dependencies("gather-package-list.nasl");
  script_require_keys("ssh/login/release");
  exit(0);
}


include("pkg-lib-rpm.inc");
include("revisions-lib.inc");

release = get_kb_item("ssh/login/release");

if(release == NULL){
  exit(0);
}

if(release == "RHENT_5")
{

  if(isrpmvuln(pkg:"samba", rpm:"samba~3.0.28~1.el5_2.1", rls:"RHENT_5"))
  {
    security_hole(0);
    exit(0);
  }

  if(isrpmvuln(pkg:"samba-client", rpm:"samba-client~3.0.28~1.el5_2.1", rls:"RHENT_5"))
  {
    security_hole(0);
    exit(0);
  }

  if(isrpmvuln(pkg:"samba-common", rpm:"samba-common~3.0.28~1.el5_2.1", rls:"RHENT_5"))
  {
    security_hole(0);
    exit(0);
  }

  if(isrpmvuln(pkg:"samba-debuginfo", rpm:"samba-debuginfo~3.0.28~1.el5_2.1", rls:"RHENT_5"))
  {
    security_hole(0);
    exit(0);
  }

  if(isrpmvuln(pkg:"samba-swat", rpm:"samba-swat~3.0.28~1.el5_2.1", rls:"RHENT_5"))
  {
    security_hole(0);
    exit(0);
  }

  exit(0);
}