###############################################################################
# OpenVAS Vulnerability Test
#
# Ubuntu Update for gnutls12, gnutls13, gnutls26 regression USN-678-2
#
# Authors:
# System Generated Check
#
# Copyright:
# Copyright (c) 2009 Intevation GmbH, http://www.intevation.net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# (or any later version), as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
###############################################################################

if(description)
{
  script_id(840346);
  script_version("$Revision: 1.0 $");
  script_xref(name: "USN", value: "678-2");
  script_cve_id("CVE-2008-4989");
  script_name(english: "Ubuntu Update for gnutls12, gnutls13, gnutls26 regression USN-678-2");
  desc["english"] = "

  Vulnerability Insight:

  USN-678-1 fixed a vulnerability in GnuTLS. The upstream patch introduced a
  regression when validating certain certificate chains that would report valid
  certificates as untrusted. This update fixes the problem.
  
  We apologize for the inconvenience.
  
  Original advisory details:
  
  Martin von Gagern discovered that GnuTLS did not properly verify certificate
  chains when the last certificate in the chain was self-signed. If a remote
  attacker were able to perform a man-in-the-middle attack, this flaw could be
  exploited to view sensitive information. (CVE-2008-4989)

  Affected Software/OS:
  gnutls12, gnutls13, gnutls26 regression on Ubuntu 6.06 LTS ,
  Ubuntu 7.10 ,
  Ubuntu 8.04 LTS ,
  Ubuntu 8.10

  Fix: Please Install the Updated Packages.

  References:
  https://lists.ubuntu.com/archives/ubuntu-security-announce/2008-December/000801.html

  Risk factor: High";

  script_description(english:desc["english"]);
  script_summary(english:"Check for the Version of gnutls12, gnutls13, gnutls26 regression");
  script_category(ACT_GATHER_INFO);
  script_copyright(english:"Copyright (C) 2009 Intevation GmbH");
  script_family(english:"Ubuntu Local Security Checks");
  script_dependencies("gather-package-list.nasl");
  script_require_keys("ssh/login/release");
  exit(0);
}


include("pkg-lib-deb.inc");
include("revisions-lib.inc");

release = get_kb_item("ssh/login/release");

if(release == NULL){
  exit(0);
}

if(release == "UBUNTU6.06 LTS")
{

  if(isdpkgvuln(pkg:"libgnutls-dev", ver:"1.2.9-2ubuntu1.4", rls:"UBUNTU6.06 LTS"))
  {
    security_hole(0);
    exit(0);
  }

  if(isdpkgvuln(pkg:"libgnutls12", ver:"1.2.9-2ubuntu1.4", rls:"UBUNTU6.06 LTS"))
  {
    security_hole(0);
    exit(0);
  }

  if(isdpkgvuln(pkg:"gnutls-bin", ver:"1.2.9-2ubuntu1.4", rls:"UBUNTU6.06 LTS"))
  {
    security_hole(0);
    exit(0);
  }

  if(isdpkgvuln(pkg:"libgnutls12-dbg", ver:"1.2.9-2ubuntu1.4", rls:"UBUNTU6.06 LTS"))
  {
    security_hole(0);
    exit(0);
  }

  exit(0);
}


if(release == "UBUNTU8.10")
{

  if(isdpkgvuln(pkg:"libgnutls-dev", ver:"2.4.1-1ubuntu0.2", rls:"UBUNTU8.10"))
  {
    security_hole(0);
    exit(0);
  }

  if(isdpkgvuln(pkg:"libgnutls26-dbg", ver:"2.4.1-1ubuntu0.2", rls:"UBUNTU8.10"))
  {
    security_hole(0);
    exit(0);
  }

  if(isdpkgvuln(pkg:"libgnutls26", ver:"2.4.1-1ubuntu0.2", rls:"UBUNTU8.10"))
  {
    security_hole(0);
    exit(0);
  }

  if(isdpkgvuln(pkg:"gnutls-bin", ver:"2.4.1-1ubuntu0.2", rls:"UBUNTU8.10"))
  {
    security_hole(0);
    exit(0);
  }

  if(isdpkgvuln(pkg:"guile-gnutls", ver:"2.4.1-1ubuntu0.2", rls:"UBUNTU8.10"))
  {
    security_hole(0);
    exit(0);
  }

  if(isdpkgvuln(pkg:"gnutls-doc", ver:"2.4.1-1ubuntu0.2", rls:"UBUNTU8.10"))
  {
    security_hole(0);
    exit(0);
  }

  exit(0);
}


if(release == "UBUNTU8.04 LTS")
{

  if(isdpkgvuln(pkg:"libgnutls-dev", ver:"2.0.4-1ubuntu2.3", rls:"UBUNTU8.04 LTS"))
  {
    security_hole(0);
    exit(0);
  }

  if(isdpkgvuln(pkg:"libgnutls13-dbg", ver:"2.0.4-1ubuntu2.3", rls:"UBUNTU8.04 LTS"))
  {
    security_hole(0);
    exit(0);
  }

  if(isdpkgvuln(pkg:"libgnutls13", ver:"2.0.4-1ubuntu2.3", rls:"UBUNTU8.04 LTS"))
  {
    security_hole(0);
    exit(0);
  }

  if(isdpkgvuln(pkg:"libgnutlsxx13", ver:"2.0.4-1ubuntu2.3", rls:"UBUNTU8.04 LTS"))
  {
    security_hole(0);
    exit(0);
  }

  if(isdpkgvuln(pkg:"gnutls-bin", ver:"2.0.4-1ubuntu2.3", rls:"UBUNTU8.04 LTS"))
  {
    security_hole(0);
    exit(0);
  }

  if(isdpkgvuln(pkg:"gnutls-doc", ver:"2.0.4-1ubuntu2.3", rls:"UBUNTU8.04 LTS"))
  {
    security_hole(0);
    exit(0);
  }

  exit(0);
}


if(release == "UBUNTU7.10")
{

  if(isdpkgvuln(pkg:"libgnutls-dev", ver:"1.6.3-1ubuntu0.3", rls:"UBUNTU7.10"))
  {
    security_hole(0);
    exit(0);
  }

  if(isdpkgvuln(pkg:"libgnutls13-dbg", ver:"1.6.3-1ubuntu0.3", rls:"UBUNTU7.10"))
  {
    security_hole(0);
    exit(0);
  }

  if(isdpkgvuln(pkg:"libgnutls13", ver:"1.6.3-1ubuntu0.3", rls:"UBUNTU7.10"))
  {
    security_hole(0);
    exit(0);
  }

  if(isdpkgvuln(pkg:"libgnutlsxx13", ver:"1.6.3-1ubuntu0.3", rls:"UBUNTU7.10"))
  {
    security_hole(0);
    exit(0);
  }

  if(isdpkgvuln(pkg:"gnutls-bin", ver:"1.6.3-1ubuntu0.3", rls:"UBUNTU7.10"))
  {
    security_hole(0);
    exit(0);
  }

  if(isdpkgvuln(pkg:"gnutls-doc", ver:"1.6.3-1ubuntu0.3", rls:"UBUNTU7.10"))
  {
    security_hole(0);
    exit(0);
  }

  exit(0);
}