###############################################################################
# OpenVAS Vulnerability Test
# $Id: gb_wireshark_dos_vuln_mar09_win.nasl 960 2009-03-16 17:23:24Z mar $
#
# Wireshark Denial of Service Vulnerability (Win)
#
# Authors:
# Sharath S <sharaths@secpod.com>
#
# Copyright:
# Copyright (c) 2009 Intevation GmbH, http://www.intevation.net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# (or any later version), as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
###############################################################################

if(description)
{
  script_id(800374);
  script_version("$Revision: 1.0 $");
  script_cve_id("CVE-2008-6472");
  script_name(english:"Wireshark Denial of Service Vulnerability (Win)");
  desc["english"] = "

  Overview: This host is installed with Wireshark and is prone to denial
  of service vulnerability.

  Vulnerability Insight:
  Error in the WLCCP and SMTP dissector allows to exploit by triggering the
  execution into an infinite loop through specially crafted packets.

  Impact:
  Successful attacks may cause the application to crash via unspecified
  attack vectors.

  Impact Level: Application

  Affected Software/OS:
  Wireshark version prior to 1.0.5 on Windows

  Fix: Upgrade to Wireshark 1.0.5
  http://www.wireshark.org/download.html

  References:
  http://secunia.com/advisories/32840
  http://www.wireshark.org/security/wnpa-sec-2008-07.html

  CVSS Score:
    CVSS Base Score     : 4.3 (AV:N/AC:M/Au:NR/C:N/I:N/A:P)
    CVSS Temporal Score : 3.2
  Risk factor: Medium";

  script_description(english:desc["english"]);
  script_summary(english:"Check for the version of Wireshark");
  script_category(ACT_GATHER_INFO);
  script_copyright(english:"Copyright (C) 2009 Intevation GmbH");
  script_family(english:"Denial of Service");
  script_dependencies("gb_wireshark_detect_win.nasl");
  script_require_keys("Wireshark/Win/Ver");
  exit(0);
}


include("version_func.inc");

sharkVer = get_kb_item("Wireshark/Win/Ver");
if(!sharkVer){
  exit(0);
}

# Grep for Wireshark version prior to 1.0.5
if(version_is_less(version:sharkVer, test_version:"1.0.5")){
  security_warning(0);
}
